@@ -356,6 +356,14 @@ class NavigationToolbar(NavigationToolbar2QT):
             self._idMotion = self.canvas.mpl_disconnect(self._idMotion)
         NavigationToolbar2QT.zoom(self, *args)
 
+    def release_zoom(self, event):
+        NavigationToolbar2QT.release_zoom(self, event)
+        self.canvas.redraw_map()
+
+    def release_pan(self, event):
+        NavigationToolbar2QT.release_pan(self, event)
+        self.canvas.redraw_map()
+
     def motion_wp(self, event):
         self.canvas.waypoints_interactor.motion_notify_callback(event)
 
@@ -496,6 +504,9 @@ class MplSideViewCanvas(MplCanvas):
        flight track / list of waypoints.
     """
 
+    _pres_maj = np.concatenate([np.arange(top * 10, top, -top) for top in (10000, 1000, 100, 10)] + [[10]])
+    _pres_min = np.concatenate([np.arange(top * 10, top, -top // 10) for top in (10000, 1000, 100, 10)] + [[10]])
+
     def __init__(self, model=None, settings=None, numlabels=None):
         """
         Arguments:
@@ -563,51 +574,14 @@ class MplSideViewCanvas(MplCanvas):
         vaxis = self.settings_dict["vertical_axis"]
         if vaxis == "pressure":
             # Compute the position of major and minor ticks. Major ticks are labelled.
-            # By default, major ticks are drawn every 100hPa. If p_top < 100hPa,
-            # the distance is reduced to every 10hPa above 100hPa.
-            label_distance = 10000
-            label_bot = self.p_bot - (self.p_bot % label_distance)
-            major_ticks = np.arange(label_bot, self.p_top - 1, -label_distance)
-
-            # .. check step reduction to 10 hPa ..
-            if self.p_top < 10000:
-                major_ticks2 = np.arange(major_ticks[-1], self.p_top - 1, -label_distance // 10)
-                len_major_ticks = len(major_ticks)
-                major_ticks = np.resize(major_ticks,
-                                        len_major_ticks + len(major_ticks2) - 1)
-                major_ticks[len_major_ticks:] = major_ticks2[1:]
-                if self.p_top < 1000:
-                    major_ticks3 = np.arange(major_ticks[-1], self.p_top - 1, -label_distance // 100)
-                    len_major_ticks = len(major_ticks)
-                    major_ticks = np.resize(major_ticks,
-                                            len_major_ticks + len(major_ticks3) - 1)
-                    major_ticks[len_major_ticks:] = major_ticks3[1:]
-                if major_ticks[-1] != self.p_top:
-                    top = np.arange(self.p_top, 0, -100000)
-                    major_ticks = np.append(major_ticks, top)
-
+            major_ticks = self._pres_maj[(self._pres_maj <= self.p_bot) & (self._pres_maj >= self.p_top)]
+            minor_ticks = self._pres_min[(self._pres_min <= self.p_bot) & (self._pres_min >= self.p_top)]
             labels = ["{}".format(int(l / 100.))
                       if (l / 100.) - int(l / 100.) == 0 else "{}".format(float(l / 100.)) for l in major_ticks]
-
-            # .. the same for the minor ticks ..
-            p_top_minor = max(label_distance, self.p_top)
-            label_distance_minor = 1000
-            label_bot_minor = self.p_bot - (self.p_bot % label_distance_minor)
-            minor_ticks = np.arange(label_bot_minor, p_top_minor - 1,
-                                    -label_distance_minor)
-
-            if self.p_top < 10000:
-                minor_ticks2 = np.arange(minor_ticks[-1], self.p_top - 1, -label_distance_minor // 10)
-                len_minor_ticks = len(minor_ticks)
-                minor_ticks = np.resize(minor_ticks,
-                                        len_minor_ticks + len(minor_ticks2) - 1)
-                minor_ticks[len_minor_ticks:] = minor_ticks2[1:]
-                if self.p_top < 10000:
-                    minor_ticks3 = np.arange(1000, self.p_top - 1, -label_distance_minor // 100)
-                    len_minor_ticks = len(minor_ticks)
-                    minor_ticks = np.resize(minor_ticks,
-                                            len_minor_ticks + len(minor_ticks3) - 1)
-                    minor_ticks[len_minor_ticks:] = minor_ticks3[1:]
+            if len(labels) > 20:
+                labels = ["" if x.split(".")[-1][0] in "975" else x for x in labels]
+            elif len(labels) > 10:
+                labels = ["" if x.split(".")[-1][0] in "9" else x for x in labels]
             self.ax.set_ylabel("pressure (hPa)")
         elif vaxis == "pressure altitude":
             major_heights = np.arange(0, thermolib.pressure2flightlevel(self.p_top) * 0.03048, 2)
@@ -952,7 +926,6 @@ class MplTopViewCanvas(MplCanvas):
         See MapCanvas.update_with_coordinate_change(). After the map redraw,
         coordinates of all objects overlain on the map have to be updated.
         """
-
         # remove legend
         self.draw_legend(None)
 
@@ -1188,15 +1161,6 @@ class MplTopViewWidget(MplNavBarWidget):
                 action.setEnabled(False)
             elif action.text() in ["Home", "Back", "Forward"]:
                 action.triggered.connect(self.historyEvent)
-        # Identify zoom events to redraw the map, if necessary.
-        self.canvas.mpl_connect('button_release_event', self.zoomEvent)
-
-    def zoomEvent(self, event):
-        """Slot to react to zoom events. Called on button release events.
-           Redraws the map after the user has zoomed or panned the image.
-        """
-        if self.navbar.mode in ["zoom rect", "pan/zoom"]:
-            self.canvas.redraw_map()
 
     def historyEvent(self):
         """Slot to react to clicks on one of the history buttons in the
