@@ -28,13 +28,11 @@
     limitations under the License.
 """
 
-from builtins import str
-
 import functools
 import logging
-from mslib.utils import config_loader, get_projection_params, save_settings_pickle, load_settings_pickle
+from mslib.utils import config_loader, get_projection_params, save_settings_qsettings, load_settings_qsettings
 from mslib.msui import MissionSupportSystemDefaultConfig as mss_default
-from mslib.msui.mss_qt import QtGui, QtWidgets
+from mslib.msui.mss_qt import QtGui, QtWidgets, QtCore
 from mslib.msui.mss_qt import ui_topview_window as ui
 from mslib.msui.mss_qt import ui_topview_mapappearance as ui_ma
 from mslib.msui.viewwindows import MSSMplViewWindow
@@ -56,7 +54,7 @@ class MSS_TV_MapAppearanceDialog(QtWidgets.QDialog, ui_ma.Ui_MapAppearanceDialog
        defined in "ui_topview_mapappearance.py".
     """
 
-    def __init__(self, parent=None, settings_dict=None):
+    def __init__(self, parent=None, settings_dict=None, wms_connected=False):
         """
         Arguments:
         parent -- Qt widget that is parent to this widget.
@@ -76,10 +74,23 @@ class MSS_TV_MapAppearanceDialog(QtWidgets.QDialog, ui_ma.Ui_MapAppearanceDialog
                              "colour_ft_vertices": (0, 0, 0, 0),
                              "colour_ft_waypoints": (0, 0, 0, 0)}
 
+        self.wms_connected = wms_connected
+        # check parent.wms_connected to disable cbFillWaterBodies and cbFillContinents
+        if self.wms_connected:
+            self.cbFillContinents.setChecked(False)
+            self.cbFillWaterBodies.setChecked(False)
+            self.cbFillContinents.setEnabled(False)
+            self.cbFillContinents.setStyleSheet("color: black")
+            self.cbFillWaterBodies.setStyleSheet("color: black")
+        else:
+            settings_dict["fill_waterbodies"] = True
+            settings_dict["fill_continents"] = True
+            self.cbFillWaterBodies.setChecked(settings_dict["fill_waterbodies"])
+            self.cbFillContinents.setChecked(settings_dict["fill_continents"])
+            self.cbFillContinents.setEnabled(True)
+
         self.cbDrawGraticule.setChecked(settings_dict["draw_graticule"])
         self.cbDrawCoastlines.setChecked(settings_dict["draw_coastlines"])
-        self.cbFillWaterBodies.setChecked(settings_dict["fill_waterbodies"])
-        self.cbFillContinents.setChecked(settings_dict["fill_continents"])
         self.cbDrawFlightTrack.setChecked(settings_dict["draw_flighttrack"])
         self.cbLabelFlightTrack.setChecked(settings_dict["label_flighttrack"])
 
@@ -164,6 +175,9 @@ class MSSTopViewWindow(MSSMplViewWindow, ui.Ui_TopViewWindow):
         # Initialise the GUI elements (map view, items of combo boxes etc.).
         self.setup_top_view()
 
+        # Boolean to store active wms connection
+        self.wms_connected = False
+
         # Connect slots and signals.
         # ==========================
 
@@ -189,11 +203,7 @@ class MSSTopViewWindow(MSSMplViewWindow, ui.Ui_TopViewWindow):
         self.cbTools.addItems(toolitems)
 
         # Fill combobox for predefined map sections.
-        self.cbChangeMapSection.clear()
-        predefined_map_sections = config_loader(dataset="predefined_map_sections",
-                                                default=mss_default.predefined_map_sections)
-        items = sorted(predefined_map_sections.keys())
-        self.cbChangeMapSection.addItems(items)
+        self.update_predefined_maps()
 
         # Initialise the map and the flight track. Get the initial projection
         # parameters from the tables in mss_settings.
@@ -201,6 +211,15 @@ class MSSTopViewWindow(MSSMplViewWindow, ui.Ui_TopViewWindow):
         self.mpl.canvas.init_map(**kwargs)
         self.setFlightTrackModel(self.waypoints_model)
 
+    def update_predefined_maps(self, extra=None):
+        self.cbChangeMapSection.clear()
+        predefined_map_sections = config_loader(
+            dataset="predefined_map_sections", default=mss_default.predefined_map_sections)
+        self.cbChangeMapSection.addItems(sorted(predefined_map_sections.keys()))
+        if extra is not None and len(extra) > 0:
+            self.cbChangeMapSection.insertSeparator(self.cbChangeMapSection.count())
+            self.cbChangeMapSection.addItems(sorted(extra))
+
     def openTool(self, index):
         """Slot that handles requests to open control windows.
         """
@@ -214,6 +233,8 @@ class MSSTopViewWindow(MSSMplViewWindow, ui.Ui_TopViewWindow):
                     view=self.mpl.canvas,
                     parent=self,
                     wms_cache=config_loader(dataset="wms_cache", default=mss_default.wms_cache))
+                widget.signal_disable_cbs.connect(self.disable_cbs)
+                widget.signal_enable_cbs.connect(self.enable_cbs)
             elif index == SATELLITE:
                 title = "Satellite Track Prediction"
                 widget = sat.SatelliteControlWidget(view=self.mpl.canvas)
@@ -229,34 +250,36 @@ class MSSTopViewWindow(MSSMplViewWindow, ui.Ui_TopViewWindow):
             # Create the actual dock widget containing <widget>.
             self.createDockWidget(index, title, widget)
 
+    @QtCore.Slot()
+    def disable_cbs(self):
+        self.wms_connected = True
+
+    @QtCore.Slot()
+    def enable_cbs(self):
+        self.wms_connected = False
+
     def changeMapSection(self, index=0, only_kwargs=False):
         """Change the current map section to one of the predefined regions.
         """
         # Get the initial projection parameters from the tables in mss_settings.
-        current_map_key = str(self.cbChangeMapSection.currentText())
-        predefined_map_sections = config_loader(dataset="predefined_map_sections",
-                                                default=mss_default.predefined_map_sections)
-        current_map = predefined_map_sections[current_map_key]
-        crs_to_mpl_basemap_table = config_loader(dataset="crs_to_mpl_basemap_table",
-                                                 default=mss_default.crs_to_mpl_basemap_table)
-        proj_params = crs_to_mpl_basemap_table.get(current_map["CRS"])
-        if proj_params is None:
-            proj_params = get_projection_params(current_map["CRS"])
-        if proj_params is None:
-            raise ValueError(u"unknown EPSG code: {:}".format(current_map["CRS"]))
+        current_map_key = self.cbChangeMapSection.currentText()
+        predefined_map_sections = config_loader(
+            dataset="predefined_map_sections", default=mss_default.predefined_map_sections)
+        current_map = predefined_map_sections.get(
+            current_map_key, {"CRS": current_map_key, "map": {}})
+        proj_params = get_projection_params(current_map["CRS"])
 
         # Create a keyword arguments dictionary for basemap that contains
         # the projection parameters.
         kwargs = current_map["map"]
-        kwargs.update({"CRS": current_map["CRS"]})
-        kwargs.update({"BBOX_UNITS": proj_params["bbox"]})
+        kwargs.update({"CRS": current_map["CRS"], "BBOX_UNITS": proj_params["bbox"]})
         kwargs.update(proj_params["basemap"])
 
         if only_kwargs:
             # Return kwargs dictionary and do NOT redraw the map.
             return kwargs
 
-        logging.debug("switching to map section %s", current_map_key)
+        logging.debug("switching to map section '%s' - '%s'", current_map_key, kwargs)
         self.mpl.canvas.redraw_map(kwargs)
 
     def setIdentifier(self, identifier):
@@ -267,7 +290,7 @@ class MSSTopViewWindow(MSSMplViewWindow, ui.Ui_TopViewWindow):
         """
         """
         settings = self.getView().get_map_appearance()
-        dlg = MSS_TV_MapAppearanceDialog(parent=self, settings_dict=settings)
+        dlg = MSS_TV_MapAppearanceDialog(parent=self, settings_dict=settings, wms_connected=self.wms_connected)
         dlg.setModal(True)
         if dlg.exec_() == QtWidgets.QDialog.Accepted:
             settings = dlg.get_settings()
@@ -280,13 +303,11 @@ class MSSTopViewWindow(MSSMplViewWindow, ui.Ui_TopViewWindow):
         """Save the current settings (map appearance) to the file
            self.settingsfile.
         """
-        # TODO: ConfigParser and a central configuration file might be the better solution than pickle.
-        # http://stackoverflow.com/questions/200599/whats-the-best-way-to-store-simple-user-settings-in-python
         settings = self.getView().get_map_appearance()
-        save_settings_pickle(self.settings_tag, settings)
+        save_settings_qsettings(self.settings_tag, settings)
 
     def load_settings(self):
         """Load settings from the file self.settingsfile.
         """
-        settings = load_settings_pickle(self.settings_tag, {})
+        settings = load_settings_qsettings(self.settings_tag, {})
         self.getView().set_map_appearance(settings)
