@@ -29,7 +29,7 @@
 import importlib
 
 from mslib.mswms.mpl_hsec import MPLBasemapHorizontalSectionStyle
-from mslib._tests.utils import SERVER_CONFIG_FILE
+from mslib._tests.constants import SERVER_CONFIG_FILE
 
 
 class TestMPLBasemapHorizontalSectionStyle(object):
@@ -41,4 +41,5 @@ class TestMPLBasemapHorizontalSectionStyle(object):
 
     def test_supported_crs(self):
         example = MPLBasemapHorizontalSectionStyle()
-        assert example.supported_crs() == ['EPSG:4326']
+        assert sorted(example.supported_crs()) == \
+            sorted(["EPSG:3031", "EPSG:3995", "EPSG:3857", "EPSG:4326", "MSS:stere"])
