@@ -33,13 +33,16 @@ from __future__ import division
 
 import numpy
 import scipy.integrate
+import logging
 
 
 class VapourPressureError(Exception):
     """Exception class to handle error arising during the computation of vapour
        pressures.
     """
-    pass
+
+    def __init__(self, error_string):
+        logging.debug("{}".format(error_string))
 
 
 def sat_vapour_pressure(t, liquid='HylandWexler', ice='GoffGratch',
@@ -280,8 +283,8 @@ def sat_vapour_pressure(t, liquid='HylandWexler', ice='GoffGratch',
                                         0.000367 * t[idx_liq] +
                                         numpy.tanh(0.0415 * (t[idx_liq] - 218.8)) *
                                         (53.878 - (1331.22 / t[idx_liq]) -
-                                        9.44523 * numpy.log(t[idx_liq]) +
-                                        0.014025 * t[idx_liq])) / 100.)
+                                         9.44523 * numpy.log(t[idx_liq]) +
+                                         0.014025 * t[idx_liq])) / 100.)
 
         else:
             raise VapourPressureError(u"Unkown method for computing "
@@ -408,11 +411,11 @@ def rel_hum(p, t, q, liquid='HylandWexler', ice='GoffGratch',
     Returns: Relative humidity in [%]. Same dimension as input fields.
     """
     if not (numpy.isscalar(p) or numpy.isscalar(t) or numpy.isscalar(q)):
-        if type(p) is not numpy.ndarray:
+        if not isinstance(p, numpy.ndarray):
             p = numpy.array(p)
-        if type(t) is not numpy.ndarray:
+        if not isinstance(t, numpy.ndarray):
             t = numpy.array(t)
-        if type(q) is not numpy.ndarray:
+        if not isinstance(q, numpy.ndarray):
             q = numpy.array(q)
 
     # Compute mixing ratio w from specific humidiy q.
@@ -455,9 +458,9 @@ def virt_temp(t, q, method='exact'):
     Returns: Virtual temperature in [K]. Same dimension as input fields.
     """
     if not (numpy.isscalar(t) or numpy.isscalar(q)):
-        if type(t) is not numpy.ndarray:
+        if not isinstance(t, numpy.ndarray):
             t = numpy.array(t)
-        if type(q) is not numpy.ndarray:
+        if not isinstance(q, numpy.ndarray):
             q = numpy.array(q)
 
     if method == 'exact':
@@ -623,9 +626,9 @@ def dewpoint_approx(p, q, method='Bolton'):
     Returns: dew point temperature in [K].
     """
     if not (numpy.isscalar(p) or numpy.isscalar(q)):
-        if type(p) is not numpy.ndarray:
+        if not isinstance(p, numpy.ndarray):
             p = numpy.array(p)
-        if type(q) is not numpy.ndarray:
+        if not isinstance(q, numpy.ndarray):
             q = numpy.array(q)
 
     # Compute mixing ratio w from specific humidiy q.
@@ -746,7 +749,7 @@ def flightlevel2pressure(flightlevel):
         static pressure (Pa)
     """
     # Convert flight level (ft) to m (1 ft = 30.48 cm; 1/0.3048m = 3.28...).
-    z = flightlevel * 100. / 3.28083989501
+    z = flightlevel * 30.48
 
     # g and R are used by all equations below.
     g = 9.80665
@@ -755,20 +758,20 @@ def flightlevel2pressure(flightlevel):
     if z <= 11000.:
         # ICAO standard atmosphere between 0 and 11 km: T(z=0km) = 15 degC,
         # p(z=0km) = 1013.25 hPa. Temperature gradient is 6.5 K/km.
-        z0 = 0
+        z0 = 0.
         T0 = 288.15
         gamma = 6.5e-3
         p0 = 101325.
 
         # Hydrostatic equation with linear temperature gradient.
-        p = p0 * (((T0 - gamma * z) / (T0 - gamma * z0))) ** (g / (gamma * R))
+        p = p0 * ((T0 - gamma * z - z0) / T0) ** (g / (gamma * R))
         return p
 
     elif z <= 20000.:
         # ICAO standard atmosphere between 11 and 20 km: T(z=11km) = -56.5 degC,
         # p(z=11km) = 226.32 hPa. Temperature is constant at -56.5 degC.
         z0 = 11000.
-        p0 = 22632.
+        p0 = 22632.64
         T = 216.65
 
         # Hydrostatic equation with constant temperature profile.
@@ -781,15 +784,50 @@ def flightlevel2pressure(flightlevel):
         z0 = 20000.
         T0 = 216.65
         gamma = -1.0e-3
-        p0 = 5475.006582501095
+        p0 = 5475.16
 
         # Hydrostatic equation with linear temperature gradient.
-        p = p0 * ((T0 - gamma * z) / (T0 - gamma * z0)) ** (g / (gamma * R))
+        p = p0 * ((T0 - gamma * (z - z0)) / T0) ** (g / (gamma * R))
+        return p
+
+    elif z <= 47000.:
+        # ICAO standard atmosphere between 32 and 47 km: T(z=32km) = -44.5 degC,
+        # p(z=32km) = 8.68019 hPa. Temperature gradient is -2.8 K/km.
+        z0 = 32000.
+        T0 = 228.66
+        gamma = -2.8e-3
+        p0 = 868.089
+
+        # Hydrostatic equation with linear temperature gradient.
+        p = p0 * ((T0 - gamma * (z - z0)) / T0) ** (g / (gamma * R))
+        return p
+
+    elif z <= 51000:
+        # ICAO standard atmosphere between 47 and 51 km: T(z=47km) = -2.5 degC,
+        # p(z=47km) = 1.10906 hPa. Temperature is constant at -2.5 degC.
+        z0 = 47000.
+        p0 = 110.928
+        T = 270.65
+
+        # Hydrostatic equation with constant temperature profile.
+        p = p0 * numpy.exp(-g * (z - z0) / (R * T))
+        return p
+
+    elif z <= 71000:
+        # ICAO standard atmosphere between 51 and 71 km: T(z=51km) = -2.5 degC,
+        # p(z=71km) = 0.66939 hPa. Temperature gradient is 2.8 K/km.
+        z0 = 51000.
+        T0 = 270.65
+        gamma = 2.8e-3
+        p0 = 66.952
+
+        # Hydrostatic equation with linear temperature gradient.
+        p = p0 * ((T0 - gamma * (z - z0)) / T0) ** (g / (gamma * R))
         return p
 
     else:
         raise ValueError("flight level to pressure conversion not "
-                         "implemented for z > 32km")
+                         "implemented for z > 71km")
 
 
 def pressure2flightlevel(p):
@@ -810,26 +848,58 @@ def pressure2flightlevel(p):
     g = 9.80665
     R = 287.058
 
-    if p < 1011.:
+    if p < 3.956:
         raise ValueError("pressure to flight level conversion not "
-                         "implemented for z > 32km (p ~ 10.11 hPa)")
+                         "implemented for z > 71km (p ~ 4 Pa)")
 
-    elif p < 5475.006582501095:
+    elif p <= 66.952:
+        # ICAO standard atmosphere between 51 and 71 km: T(z=51km) = -2.5 degC,
+        # p(z=71km) = 0.66939 hPa. Temperature gradient is 2.8 K/km.
+        z0 = 51000.
+        T0 = 270.65
+        gamma = 2.8e-3
+        p0 = 66.952
+
+        # Hydrostatic equation with linear temperature gradient.
+        z = z0 + 1. / gamma * (T0 - T0 * numpy.exp(gamma * R / g * numpy.log(p / p0)))
+
+    elif p < 110.928:
+        # ICAO standard atmosphere between 47 and 51 km: T(z=47km) = -2.5 degC,
+        # p(z=47km) = 1.10906 hPa. Temperature is constant at -2.5 degC.
+        z0 = 47000.
+        p0 = 110.928
+        T = 270.65
+
+        # Hydrostatic equation with constant temperature profile.
+        z = z0 - (R * T) / g * numpy.log(p / p0)
+
+    elif p < 868.089:
+        # ICAO standard atmosphere between 32 and 47 km: T(z=32km) = -44.5 degC,
+        # p(z=32km) = 54.75 hPa. Temperature gradient is -2.8 K/km.
+        z0 = 32000.
+        T0 = 228.66
+        gamma = -2.8e-3
+        p0 = 868.089
+
+        # Hydrostatic equation with linear temperature gradient.
+        z = z0 + 1. / gamma * (T0 - T0 * numpy.exp(gamma * R / g * numpy.log(p / p0)))
+
+    elif p < 5474.16:
         # ICAO standard atmosphere between 20 and 32 km: T(z=20km) = -56.5 degC,
         # p(z=20km) = 54.75 hPa. Temperature gradient is -1.0 K/km.
         z0 = 20000.
         T0 = 216.65
         gamma = -1.0e-3
-        p0 = 5475.006582501095
+        p0 = 5475.16
 
         # Hydrostatic equation with linear temperature gradient.
-        z = 1. / gamma * (T0 - (T0 - gamma * z0) * numpy.exp(gamma * R / g * numpy.log(p / p0)))
+        z = z0 + 1. / gamma * (T0 - T0 * numpy.exp(gamma * R / g * numpy.log(p / p0)))
 
     elif p < 22632.:
         # ICAO standard atmosphere between 11 and 20 km: T(z=11km) = -56.5 degC,
         # p(z=11km) = 226.32 hPa. Temperature is constant at -56.5 degC.
         z0 = 11000.
-        p0 = 22632.
+        p0 = 22632.64
         T = 216.65
 
         # Hydrostatic equation with constant temperature profile.
@@ -844,10 +914,10 @@ def pressure2flightlevel(p):
         p0 = 101325.
 
         # Hydrostatic equation with linear temperature gradient.
-        z = 1. / gamma * (T0 - (T0 - gamma * z0) * numpy.exp(gamma * R / g * numpy.log(p / p0)))
+        z = 1. / gamma * (T0 - T0 * numpy.exp(gamma * R / g * numpy.log(p / p0)))
 
     # Convert from m to flight level (ft).
-    flightlevel = z * 3.28083989501 / 100.
+    flightlevel = z * 0.0328083989502
 
     return flightlevel
 
@@ -858,7 +928,7 @@ def flightlevel2pressure_a(flightlevel):
     hydrostatic equation, according to the profile of the ICAO
     standard atmosphere.
 
-    Array version, the argument "p" must be a numpy array.
+    Array version, the argument "flightlevel" must be a numpy array.
 
     Reference:
         For example, H. Kraus, Die Atmosphaere der Erde, Springer, 2001,
@@ -870,15 +940,15 @@ def flightlevel2pressure_a(flightlevel):
         static pressure (Pa)
     """
     # Make sure flightlevel is a numpy array.
-    if type(flightlevel) is not numpy.ndarray:
+    if not isinstance(flightlevel, numpy.ndarray):
         raise ValueError("argument flightlevel must be a numpy array")
 
     # Convert flight level (ft) to m (1 ft = 30.48 cm; 1/0.3048m = 3.28...).
-    z = flightlevel * 100. / 3.28083989501
+    z = flightlevel * 30.48
 
-    if (z > 32000.).any():
+    if (z > 71000).any():
         raise ValueError("flight level to pressure conversion not "
-                         "implemented for z > 32km")
+                         "implemented for z > 71km")
 
     # g and R are used by all equations below.
     g = 9.80665
@@ -889,20 +959,20 @@ def flightlevel2pressure_a(flightlevel):
 
     # ICAO standard atmosphere between 0 and 11 km: T(z=0km) = 15 degC,
     # p(z=0km) = 1013.25 hPa. Temperature gradient is 6.5 K/km.
-    indices = numpy.where(z <= 11000.)
+    indices = z <= 11000.
     z0 = 0
     T0 = 288.15
     gamma = 6.5e-3
     p0 = 101325.
 
     # Hydrostatic equation with linear temperature gradient.
-    p[indices] = p0 * (((T0 - gamma * z[indices]) / (T0 - gamma * z0))) ** ((g / (gamma * R)))
+    p[indices] = p0 * ((T0 - gamma * (z[indices] - z0)) / T0) ** (g / (gamma * R))
 
     # ICAO standard atmosphere between 11 and 20 km: T(z=11km) = -56.5 degC,
     # p(z=11km) = 226.32 hPa. Temperature is constant at -56.5 degC.
-    indices = numpy.where((z > 11000.) & (z <= 20000.))
+    indices = (z > 11000.) & (z <= 20000.)
     z0 = 11000.
-    p0 = 22632.
+    p0 = 22632.64
     T = 216.65
 
     # Hydrostatic equation with constant temperature profile.
@@ -910,19 +980,51 @@ def flightlevel2pressure_a(flightlevel):
 
     # ICAO standard atmosphere between 20 and 32 km: T(z=20km) = -56.5 degC,
     # p(z=20km) = 54.75 hPa. Temperature gradient is -1.0 K/km.
-    indices = numpy.where((z > 20000.) & (z <= 32000.))
+    indices = (z > 20000.) & (z <= 32000.)
     z0 = 20000.
     T0 = 216.65
     gamma = -1.0e-3
-    p0 = 5475.006582501095
+    p0 = 5475.16
 
     # Hydrostatic equation with linear temperature gradient.
-    p[indices] = p0 * (((T0 - gamma * z[indices]) / (T0 - gamma * z0))) ** (g / (gamma * R))
+    p[indices] = p0 * ((T0 - gamma * (z[indices] - z0)) / T0) ** (g / (gamma * R))
+
+    # ICAO standard atmosphere between 32 and 47 km: T(z=32km) = -44.5 degC,
+    # p(z=32km) = 8.68019 hPa. Temperature gradient is -2.8 K/km.
+    indices = (z > 32000.) & (z <= 47000.)
+    z0 = 32000.
+    T0 = 228.66
+    gamma = -2.8e-3
+    p0 = 868.089
+
+    # Hydrostatic equation with linear temperature gradient.
+    p[indices] = p0 * ((T0 - gamma * (z[indices] - z0)) / T0) ** (g / (gamma * R))
+
+    # ICAO standard atmosphere between 47 and 51 km: T(z=47km) = -2.5 degC,
+    # p(z=47km) = 1.10906 hPa. Temperature is constant at -2.5 degC.
+    indices = (z > 47000.) & (z <= 51000)
+    z0 = 47000.
+    T = 270.65
+    p0 = 110.928
+
+    # Hydrostatic equation with constant temperature profile.
+    p[indices] = p0 * numpy.exp(-g * (z[indices] - z0) / (R * T))
+
+    # ICAO standard atmosphere between 51 and 71 km: T(z=51km) = -2.5 degC,
+    # p(z=71km) = 0.66939 hPa. Temperature gradient is 2.8 K/km.
+    indices = (z > 51000.) & (z <= 71000)
+    z0 = 51000.
+    T0 = 270.65
+    gamma = 2.8e-3
+    p0 = 66.952
+
+    # Hydrostatic equation with linear temperature gradient.
+    p[indices] = p0 * ((T0 - gamma * (z[indices] - z0)) / T0) ** (g / (gamma * R))
 
     return p
 
 
-def pressure2flightlevel_a(p, fake_above_32km=False):
+def pressure2flightlevel_a(p):
     """
     Conversion of pressure (Pa) to flight level (hft) with
     hydrostatic equation, according to the profile of the ICAO
@@ -944,36 +1046,68 @@ def pressure2flightlevel_a(p, fake_above_32km=False):
         flight level in hft
     """
     # Make sure p is a numpy array.
-    if type(p) is not numpy.ndarray:
+    if not isinstance(p, numpy.ndarray):
         raise ValueError("argument p must be a numpy array")
 
     # g and R are used by all equations below.
     g = 9.80665
     R = 287.058
 
-    if (p < 1011.).any() and not fake_above_32km:
+    if (p < 3.9591).any():
         raise ValueError("pressure to flight level conversion not "
-                         "implemented for z > 32km (p ~ 10.11 hPa)")
+                         "implemented for z > 71km (p ~ 4 Pa)")
 
     # Initialize the return array.
-    z = numpy.zeros(p.shape)
+    z = numpy.zeros_like(p)
+
+    indices = p < 66.952
+    # ICAO standard atmosphere between 51 and 71 km: T(z=51km) = -2.5 degC,
+    # p(z=71km) = 0.66939 hPa. Temperature gradient is 2.8 K/km.
+    z0 = 51000.
+    T0 = 270.65
+    gamma = 2.8e-3
+    p0 = 66.952
+
+    # Hydrostatic equation with linear temperature gradient.
+    z[indices] = z0 + 1. / gamma * (T0 - T0 * numpy.exp(gamma * R / g * numpy.log(p[indices] / p0)))
+
+    # ICAO standard atmosphere between 47 and 51km: T(z=47km) = -2.5 degC,
+    # p(z=11km) = 1.10906 hPa. Temperature is constant at -2.5 degC.
+    indices = (p >= 66.952) & (p < 110.928)
+    z0 = 47000.
+    p0 = 110.928
+    T = 270.65
+
+    # Hydrostatic equation with constant temperature profile.
+    z[indices] = z0 - (R * T) / g * numpy.log(p[indices] / p0)
+
+    # ICAO standard atmosphere between 32 and 47 km: T(z=32km) = -44.5 degC,
+    # p(z=20km) = 8.68019 hPa. Temperature gradient is -2.8 K/km.
+    indices = (p >= 110.928) & (p < 868.089)
+    z0 = 32000.
+    T0 = 228.66
+    gamma = -2.8e-3
+    p0 = 868.089
+
+    # Hydrostatic equation with linear temperature gradient.
+    z[indices] = z0 + 1. / gamma * (T0 - T0 * numpy.exp(gamma * R / g * numpy.log(p[indices] / p0)))
 
     # ICAO standard atmosphere between 20 and 32 km: T(z=20km) = -56.5 degC,
     # p(z=20km) = 54.75 hPa. Temperature gradient is -1.0 K/km.
-    indices = numpy.where(p < 5475.006582501095)
+    indices = (p >= 868.089) & (p < 5474.16)
     z0 = 20000.
     T0 = 216.65
     gamma = -1.0e-3
-    p0 = 5475.006582501095
+    p0 = 5475.16
 
     # Hydrostatic equation with linear temperature gradient.
-    z[indices] = 1. / gamma * (T0 - (T0 - gamma * z0) * numpy.exp(gamma * R / g * numpy.log(p[indices] / p0)))
+    z[indices] = z0 + 1. / gamma * (T0 - T0 * numpy.exp(gamma * R / g * numpy.log(p[indices] / p0)))
 
     # ICAO standard atmosphere between 11 and 20 km: T(z=11km) = -56.5 degC,
     # p(z=11km) = 226.32 hPa. Temperature is constant at -56.5 degC.
-    indices = numpy.where((p >= 5475.006582501095) & (p < 22632.))
+    indices = (p >= 5474.16) & (p < 22632.)
     z0 = 11000.
-    p0 = 22632.
+    p0 = 22632.64
     T = 216.65
 
     # Hydrostatic equation with constant temperature profile.
@@ -981,17 +1115,17 @@ def pressure2flightlevel_a(p, fake_above_32km=False):
 
     # ICAO standard atmosphere between 0 and 11 km: T(z=0km) = 15 degC,
     # p(z=0km) = 1013.25 hPa. Temperature gradient is 6.5 K/km.
-    indices = numpy.where(p >= 22632.)
+    indices = p >= 22632.
     z0 = 0
     T0 = 288.15
     gamma = 6.5e-3
     p0 = 101325.
 
     # Hydrostatic equation with linear temperature gradient.
-    z[indices] = 1. / gamma * (T0 - (T0 - gamma * z0) * numpy.exp(gamma * R / g * numpy.log(p[indices] / p0)))
+    z[indices] = 1. / gamma * (T0 - T0 * numpy.exp(gamma * R / g * numpy.log(p[indices] / p0)))
 
     # Convert from m to flight level (ft).
-    flightlevel = z * 3.28083989501 / 100.
+    flightlevel = z * 0.0328083989502
 
     return flightlevel
 
@@ -1010,7 +1144,7 @@ def isa_temperature(flightlevel):
         temperature (K)
     """
     # Convert flight level (ft) to m (1 ft = 30.48 cm; 1/0.3048m = 3.28...).
-    z = flightlevel * 100. / 3.28083989501
+    z = flightlevel * 30.48
 
     if z <= 11000.:
         # ICAO standard atmosphere between 0 and 11 km: T(z=0km) = 15 degC,
@@ -1033,6 +1167,20 @@ def isa_temperature(flightlevel):
         gamma = -1.0e-3
         return T0 - gamma * (z - z0)
 
+    elif z <= 47000.:
+        # ICAO standard atmosphere between 32 and 47 km: T(z=32km) = -44.5 degC,
+        # p(z=32km) = 8.68019 hPa. Temperature gradient is -2.8 K/km.
+        z0 = 32000.
+        T0 = 228.65
+        gamma = -2.8e-3
+        return T0 - gamma * (z - z0)
+
+    elif z <= 47820.070345213892438:
+        # ICAO standard atmosphere between 47 and 47820.070345213892438 km: T(z=47km) = -2.5 degC,
+        # p(z=47km) = 1.10906 hPa. Temperature is constant at -2.5 degC.
+        T = 270.65
+        return T
+
     else:
         raise ValueError("ISA temperature from flight level not "
-                         "implemented for z > 32km")
+                         "implemented for z > 71km")
